@@ -184,15 +184,14 @@ GCJ_New (NPMIMEType pluginType, NPP instance, uint16 mode,
   applet_tag = g_strconcat (applet_tag,
 			    g_strdup_printf ("></EMBED>"), NULL);
 
-  data->instance_id = g_strdup_printf ("applet%d", instance_counter++);
+  data->instance_id = g_strdup_printf ("instance applet%d", instance_counter++);
 
   instance->pdata = data;
 
-  send_message_to_appletviewer ("instance");
+  char* tag = g_strdup_printf ("tag %s %s", data->documentbase, applet_tag);
+  
   send_message_to_appletviewer (data->instance_id);
-  send_message_to_appletviewer ("tag");
-  send_message_to_appletviewer (data->documentbase);
-  send_message_to_appletviewer (applet_tag);
+  send_message_to_appletviewer (tag);
 
   return NPERR_NO_ERROR;
 }
@@ -213,8 +212,6 @@ GCJ_Destroy (NPP instance, NPSavedData** save)
 
   GCJPluginData* data = (GCJPluginData*) instance->pdata;
 
-  send_message_to_appletviewer ("instance");
-  send_message_to_appletviewer (data->instance_id);
   send_message_to_appletviewer ("destroy");
 
   gcjplugindata_destroy (&data);
@@ -267,23 +264,19 @@ GCJ_SetWindow (NPP instance, NPWindow* window)
 	    {
 	      // The window is the same as it was for the last
 	      // SetWindow call.
-	      char* width = g_strdup_printf ("%d", window->width);
+	      char* width = g_strdup_printf ("width %d", window->width);
 	      if (g_ascii_strcasecmp (width, data->width))
 		{
 		  // The width of the plugin window has changed.
-		  send_message_to_appletviewer ("instance");
 		  send_message_to_appletviewer (data->instance_id);
-		  send_message_to_appletviewer ("width");
 		  send_message_to_appletviewer (data->width);
 		}
 
-	      char* height = g_strdup_printf ("%d", window->height);
+	      char* height = g_strdup_printf ("height %d", window->height);
 	      if (g_ascii_strcasecmp (height, data->height))
 		{
 		  // The height of the plugin window has changed.
-		  send_message_to_appletviewer ("instance");
 		  send_message_to_appletviewer (data->instance_id);
-		  send_message_to_appletviewer ("height");
 		  send_message_to_appletviewer (data->height);
 		}
 	    }
@@ -302,11 +295,9 @@ GCJ_SetWindow (NPP instance, NPWindow* window)
   else
     {
       PLUGIN_DEBUG ("GCJ_SetWindow: setting window\n");
-      data->xid = g_strdup_printf ("%d", (int)(window->window));
+      data->xid = g_strdup_printf ("xid %d", (int)(window->window));
 
-      send_message_to_appletviewer ("instance");
       send_message_to_appletviewer (data->instance_id);
-      send_message_to_appletviewer ("xid");
       send_message_to_appletviewer (data->xid);
     }
 
@@ -404,15 +395,6 @@ send_message_to_appletviewer (gchar const* name)
       return NPERR_GENERIC_ERROR;
     }
 
-  PIPE_OUTPUT_DEBUG (name);
-
-  gchar *recv_name = g_strdup (name);
-
-  if ((np_error = receive_message_from_appletviewer (recv_name)) != NPERR_NO_ERROR)
-    return np_error;
-
-  g_printerr ("send_message_to_appletviewer: Success: %s\n", recv_name);
-
   return NPERR_NO_ERROR;
 }
 
@@ -433,17 +415,6 @@ receive_message_from_appletviewer (gchar *str)
 
   PIPE_INPUT_DEBUG (read_buf);
 
-  read_buf = g_strchomp (read_buf);
-
-  str = g_strchomp (str);
-
-  if (g_ascii_strcasecmp (str, read_buf))
-    {
-      g_printerr ("receive_message_from_appletviewer: "
-                  "Error: did not receive expected confirmation from gcjappletviewer\n");
-      return NPERR_GENERIC_ERROR;
-    }
-
   return NPERR_NO_ERROR;
 }
 
@@ -661,6 +632,13 @@ NP_Shutdown(void)
 	}
     }
 
+  // Delete named pipes.
+  gchar *pipename_in = g_strdup_printf ("/tmp/gcjwebplugin-%i-in", getpid ());
+  gchar *pipename_out = g_strdup_printf ("/tmp/gcjwebplugin-%i-out", getpid ());
+
+  unlink (pipename_in);
+  unlink (pipename_out);
+
   g_printerr ("Done shutting down.\n");
 
   return NPERR_NO_ERROR;
