@@ -1,5 +1,5 @@
 /* PluginAppletWindow.java -- an embeddable applet window
-   Copyright (C) 2003  Thomas Fitzsimmons <fitzsim@redhat.com>
+   Copyright (C) 2003, 2004  Thomas Fitzsimmons <fitzsim@redhat.com>
 
    This file is part of GCJ Applet Viewer.
 
@@ -26,7 +26,6 @@ import java.applet.AppletContext;
 import java.awt.BorderLayout;
 import java.awt.Component;
 import java.awt.Dimension;
-import java.awt.Frame;
 import java.io.IOException;
 import java.io.StreamTokenizer;
 import java.io.StringReader;
@@ -35,65 +34,90 @@ import java.net.MalformedURLException;
 import java.net.URL;
 import java.util.HashMap;
 
+
 class PluginAppletWindow extends EmbeddedWindow
 {
-  private static HashMap contexts = new HashMap ();
+  private static int test_window_count;
+  private static HashMap contexts = new HashMap();
+  private Applet applet;
+  private AppletTag tag;
+  private AppletWarning warning;
+  private boolean isActive;
 
-  Applet applet;
-  AppletTag tag;
-  private boolean isActive = false;
-
-  PluginAppletWindow ()
+  PluginAppletWindow()
   {
-    super ();
+    super();
   }
 
-  void setTag (String tag, String documentbase, String encoding)
+  void setTag(String tag, String documentbase, String encoding)
     throws MalformedURLException, IOException
   {
-    StringReader reader = new StringReader (tag);
-    URL documentbaseURL = AppletTag.locationToURL (documentbase);
-    this.tag = AppletTag.parseNextTag (new StreamTokenizer (reader),
-				       documentbaseURL, encoding);
+    StringReader reader = new StringReader(tag);
+    URL documentbaseURL = AppletTag.locationToURL(documentbase);
+    this.tag =
+      AppletTag.parseNextTag(new StreamTokenizer(reader), documentbaseURL,
+                             encoding);
   }
 
   ///////////////////////////////////
   ////// EmbeddedWindow Method //////
   ///////////////////////////////////
 
-  public void setHandle (long handle)
+  /**
+   * Set the native handle of the window system to embed the window in.
+   *
+   * @param handle the native handle.
+   */
+  public void setHandle(long handle)
   {
-    super.setHandle (handle);
-
+    super.setHandle(handle);
     addNotify();
+    setLayout(new BorderLayout());
 
-    setLayout (new BorderLayout());
+    applet = AppletViewer.createApplet(tag);
 
-    applet = AppletViewer.createApplet (tag);
-
-    if (contexts.get (tag.codebase) == null)
-      contexts.put (tag.codebase, new PluginAppletContext ());
+    if (contexts.get(tag.codebase) == null)
+      contexts.put(tag.codebase, new PluginAppletContext());
 
     isActive = true;
+    add(applet, BorderLayout.CENTER);
 
-    add (applet, BorderLayout.CENTER);
+    AppletContext context = (AppletContext) contexts.get(tag.codebase);
+    ((PluginAppletContext) context).addApplet(applet);
+    applet.setStub(new CommonAppletStub(tag, context));
 
-    setVisible (true);
+    String test_window_count = AppletViewer.getenv("GCJAPPLETVIEWER_NOGUI");
 
-    AppletContext context = (AppletContext) contexts.get (tag.codebase);
-    ((PluginAppletContext) context).addApplet (applet);
-    applet.setStub (new AppletStub (tag, context));
-    applet.init ();
-    applet.setVisible (true);
-    applet.validate ();
-    applet.start ();
+    if (test_window_count == null)
+      {
+	setVisible(true);
+
+	applet.init();
+	applet.validate();
+	applet.start();
+      }
+    else
+      {
+	applet.init();
+	applet.start();
+
+	if (++this.test_window_count == Integer.decode(test_window_count)
+	                                       .intValue())
+	  System.exit(0);
+      }
   }
 
   /////////////////////////////
   ////// Component Method /////
   /////////////////////////////
 
-  public void doLayout ()
+  /**
+   * Prompts the layout manager to lay out this component. This is usually
+   * called when the component (more specifically, container) is validated.
+   *
+   * (description copied from java.awt.Component.doLayout())
+   */
+  public void doLayout()
   {
     super.doLayout();
 
